@@ -73,3 +73,22 @@ class TestGraphs(unittest.TestCase):
         except Exception as e:
 
             self.assertTrue(name in str(e), e)
+
+    def test_create_empty_graph(self):
+        """
+        Verify empty graph endpoint is reachable
+
+        :return:
+        """
+        name = str(uuid.uuid4())
+        raised = False
+        try:
+            m = self.graph.create_empty_graph(
+                org_id=test_org,
+                graph_name=name
+            )
+        except Exception as e:
+            m = str(e)
+            raised = True
+
+        self.assertFalse(raised, m)
