@@ -57,6 +57,10 @@ class Graph(ApiRequestManager):
 
         self.export_query_url = self.graph_query_url + "/export"
 
+        self.graph_merge_url = self.graph_url + "/merge"
+
+        #https://aws-stage-qa-1.ean.io/graph/v1/merge?name=Try+building+a+new+graph
+
     @single_org
     def get_graphs_list(self, org_id=None):
         """
@@ -137,3 +141,27 @@ class Graph(ApiRequestManager):
             return result.content
 
         raise Exception(json.loads(result.content))
+
+    @single_org
+    def create_empty_graph(self, org_id=None, *, graph_name):
+        """
+        Create an empty graph with the given name
+
+        :param org_id: Organization id where the graph would be stored
+        :param graph_name: Empty graph name
+        :return:
+        """
+
+        header = self.build_header(
+            org_id=org_id,
+            others=self.content_type_header
+        )
+
+        data = {"name": graph_name}
+
+        result = self.session.post(self.graph_merge_url, headers=header, params=data)
+
+        if result.status_code in [200, 201, 202]:
+            return json.loads(result.content)
+
+        raise Exception(json.loads(result.content))
