@@ -103,7 +103,7 @@ class GraphQLBuilder:
 
         return GqlQuery().fields(fields).fragment(fragment_name, interface_name).generate()
 
-    def build_simple_query(self, query_name, query_input: dict = None, query_alias=None, fields: list = None):
+    def build_simple_query(self, query_name, query_input=None, query_alias=None, fields: list = None):
 
         query = GqlQuery()
 
