@@ -62,6 +62,8 @@ class Pipelines(ApiRequestManager):
 
             self.run_pipeline_url = self.pipeline_url + '/run'
 
+            self.run_pipeline_status_url = self.pipeline_url + '/status'
+
             self.create_map_attributes_transf = self.pipeline_url + "/components/{}/map-attribute-rules"
 
             self.pipelines_url_v2 = self.pipelines_url + "/v2/{}"
@@ -832,6 +834,30 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(post_pipeline_request.content))
 
+    @single_org
+    def get_pipeline_run_status(self, org_id=None, *, pipeline_id):
+        """
+        Returns distinct values from a given flow, if count is true, it will return the count per distinct value
+        :param org_id:
+        :param pipeline_id:
+        :param flow_id:
+        :param col:
+        :param sort_key:
+        :param count:
+        :return:
+        """
+
+        header = self.build_header(
+            others=self.content_type_header,
+            org_id=str(org_id)
+        )
+
+        status_url = self.run_pipeline_status_url.format(org_id, pipeline_id)
+
+        run_request = self.session.get(status_url, headers=header)
+
+        return run_request.status_code, json.loads(run_request.content)
+
     @single_org
     def wait_for_pipeline(self, org_id=None, *, pipeline_id):
         """
