@@ -434,6 +434,119 @@ class Sources(ApiRequestManager):
 
         return results
 
+    @single_org
+    def append_all(self, name, org_id=None, *, file_path, format="csv",
+                   convert_to_parquet="false", encoding='UTF-8', chunks=10000, existing_dataset_id=None):
+        """
+
+        This method will split a data-set into chunks, and uplaod chunk by chunk. This is usefull for
+        limiting and not overwelm the unify cluster. Use this method when trying to upload big datasets.
+
+        :param name: Dataset name to be cerated
+        :type name: str
+        :param org_id: Org where the dataset will be created
+        :type org_id: int or str
+        :param file_path: Dataset file directory route
+        :type file_path: str
+        :param format: File format. Accepts "CSV" or "TSV"
+        :type format: str, optional
+        :param convert_to_parquet: Flag to convert file to parquet
+        :type convert_to_parquet: bool, optional
+        :param encoding: File encoding
+        :type encoding: str, optional
+        :param chunks: Number of chunks to split the file
+        :type chunks: int
+        :return:
+        """
+
+        content = open(file_path, "rb").read().decode(encoding)
+
+        data = content.encode(encoding)
+
+        jdata = csv_to_json(data, encoding=encoding)
+
+        first = True if existing_dataset_id is None else False
+
+        dataset_data = {
+            "create": {},
+            "append": []
+        }
+
+        all_groups = []
+
+        any_stage = False
+
+        dataset_id = None if existing_dataset_id is None else existing_dataset_id
+
+        for aux_file in stream_iterable(container=jdata, chunk=chunks):
+
+            if first:
+
+                first = False
+
+                file_dir, path = mkstemp(suffix=".csv")
+
+                open(path, "w", encoding=encoding).write(json_to_csv(aux_file))
+
+                dataset_data["create"] = self.create_api_data_set(
+                    name=name,
+                    org_id=org_id,
+                    file_path=path,
+                    format=format,
+                    convert_to_parquet=convert_to_parquet,
+                    encoding=encoding
+                )
+
+                dataset_id = dataset_data["create"]["data_set_id"]
+
+                Wait().until(
+                    self.is_commit_completed,
+                    "commit {} never completed".format(dataset_data["create"]["data_set_id"]),
+                    org_id,
+                    dataset_data["create"]["data_set_id"],
+                    dataset_data["create"]["commit_id"]
+                )
+
+                os.close(file_dir)
+
+            else:
+
+                try:
+                    stage_name = "file_{}".format(str(uuid.uuid4())[:5])
+
+                    if len(json_to_csv(aux_file)):
+                        stage_result = self.stage_file_with_content(
+                            name=stage_name,
+                            org_id=org_id,
+                            file_data=json_to_csv(aux_file),
+                            format=format,
+                            convert_to_parquet=convert_to_parquet,
+                            encoding=encoding
+                        )
+
+                        print(stage_result.decode())
+
+                        all_groups.append(
+                            {
+                                "groupId": stage_result.decode(),
+                                "name": stage_name
+                            }
+                        )
+
+                        any_stage = True
+
+                except Exception as err:
+                    print("skipping {}".format(repr(err)))
+
+        if any_stage:
+            dataset_data["append"] = self.append_all_command(
+                org_id=org_id,
+                files=all_groups,
+                data_set_id=dataset_id
+            )
+
+        return dataset_data
+
     @single_org
     def get_commit_status(self, org_id=None, *, data_set_id, commit_id):
         """
@@ -634,6 +747,7 @@ class Sources(ApiRequestManager):
             org_id=org_id,
             others={"'Content-Type'": "application/data"}
         )
+
         headers = dict(header.items())
         request = self.session.post(
             self.commit_data_set_url.format(data_set_id),
@@ -748,7 +862,7 @@ class Sources(ApiRequestManager):
                 [
                     {
                         "$type": "append",
-                        "name": repr(name),
+                        "name": name,
                         "group": group_id.decode(),
                         "cause": []
                     }
@@ -756,6 +870,23 @@ class Sources(ApiRequestManager):
         }
         return self._commit_dataset_command(org_id, data_set_id, command)
 
+    def append_all_command(self, org_id, data_set_id, files: list):
+
+        command = {
+            "commands":
+                [
+                    {
+                        "$type": "append-all",
+                        "files": files,
+                        "overwrite": False,
+                        "cause": []
+                    }
+                ]
+        }
+
+        open("append_all.json", "w+").write(json.dumps(command))
+        return self._commit_dataset_command(org_id, data_set_id, command)
+
     def stage_data(
             self, name, org_id, file_path, group_id=None, format="csv",
             convert_to_parquet="false", encoding='UTF-8', encode=True):
@@ -790,13 +921,13 @@ class Sources(ApiRequestManager):
 
         if group_id is None:
             payload_data = {
-                "name": repr(name),
+                "name": name,
                 "convertToParquet": convert_to_parquet,
                 "format": format
             }
         else:
             payload_data = {
-                "name": repr(name),
+                "name": name,
                 "convertToParquet": convert_to_parquet,
                 "format": format,
                 "groupId": group_id
@@ -889,16 +1020,18 @@ class Sources(ApiRequestManager):
         if group_id is None:
 
             payload_data = {
-                "name": repr(name),
+                "name": name,
                 "convertToParquet": convert_to_parquet,
-                "format": format
+                "format": format,
+                "charset": encoding
             }
         else:
             payload_data = {
-                "name": repr(name),
+                "name": name,
                 "convertToParquet": convert_to_parquet,
                 "format": format,
-                "groupId": group_id
+                "groupId": group_id,
+                "charset": encoding
             }
 
         test_request = self.session.post(
