@@ -18,10 +18,11 @@ Contains methods to interact with templates api
 import json
 import os
 
+from unify.generalutils import stream_iterable
 from unify.properties import Properties
 from unify.properties import ClusterSetting
 from unify.apirequestsmng import ApiRequestManager
-from unify.generalutils import csv_to_json
+from unify.generalutils import csv_to_json, json_to_csv
 from unify.helpers.SingleOrg import single_org
 from unify.helpers.unify_objects.Template import Template as TemplateData
 
@@ -436,6 +437,39 @@ class Templates(ApiRequestManager):
         except Exception as error:
             raise error
 
+    @single_org
+    def download_template_batches(self, org_id=None, format: str = "csv", batch_size: int = 100):
+        """
+        Retrieves all the templates data in batches
+
+        :param org_id: Org where the templates are stored
+        :type org_id: int or str
+        :param format: File format. Accepts "CSV" or "JSON"
+        :type format: str, optional
+        :param batch_size: The size of each batch
+        :type batch_size: integer, optiona
+        :return: Text representing templates
+        """
+        try:
+            template_list_resp = self.list_asset_templates(org_id=org_id)
+
+            full_list = []
+
+            for template_chunk in stream_iterable(container=template_list_resp, chunk=batch_size):
+                template_list = [template["id"] for template in template_chunk]
+
+                data = self.download_template(org_id=org_id, list_templates=template_list)
+
+                full_list.extend(csv_to_json(csv_data=data))
+
+            if format == "csv":
+                return json_to_csv(full_list)
+
+            return json.dumps(full_list)
+
+        except Exception as error:
+            raise error
+
     @single_org
     def download_all_template_config(self, org_id=None):
         """
